Bus

Struct Bus 

pub struct Bus<T> { /* private fields */ }
A channel of messages published by a Shell.

Implementations

Source

impl<T> Bus<T>

pub fn new() -> Self

Creates an empty Bus.

pub fn is_empty(&self) -> bool

Returns true if the Bus has no messages pending.

pub fn len(&self) -> usize

Returns the amount of messages pending in the Bus.

pub fn push(&mut self, message: T) -> Tracking

Pushes a new message to the Bus.

The returned Tracking can be used to determine if the message was processed.

pub fn drain(&mut self) -> impl Iterator<Item = T>

Drains the Bus.